[java-identity-provider] branch master updated: silence javadoc warning

Rod Widdowson rdw at steadingsoftware.com
Sat May 18 11:07:49 EDT 2019


This is an automated email from the git hooks/post-receive script.

rdw pushed a commit to branch master
in repository java-identity-provider.

View the commit online:
http://git.shibboleth.net/view/?p=java-identity-provider.git;a=commit;h=5eaa48c30b262d3500806a3405d0cbc1c51c991b

The following commit(s) were added to refs/heads/master by this push:
       new  5eaa48c   silence javadoc warning
5eaa48c is described below

commit 5eaa48c30b262d3500806a3405d0cbc1c51c991b
Author: Rod Widdowson <rdw at steadingsoftware.com>
AuthorDate: Sat May 18 16:07:44 2019 +0100

    silence javadoc warning
---
 .../src/main/java/net/shibboleth/idp/metrics/impl/HTTPReporter.java  | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/idp-core/src/main/java/net/shibboleth/idp/metrics/impl/HTTPReporter.java b/idp-core/src/main/java/net/shibboleth/idp/metrics/impl/HTTPReporter.java
index a8dbab1..a24daa3 100644
--- a/idp-core/src/main/java/net/shibboleth/idp/metrics/impl/HTTPReporter.java
+++ b/idp-core/src/main/java/net/shibboleth/idp/metrics/impl/HTTPReporter.java
@@ -19,6 +19,7 @@ package net.shibboleth.idp.metrics.impl;
 
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
+import java.text.DateFormat;
 import java.text.SimpleDateFormat;
 import java.util.SortedMap;
 import java.util.concurrent.ScheduledExecutorService;
@@ -98,7 +99,7 @@ public class HTTPReporter extends ScheduledReporter implements InitializableComp
     /** JSON object mapper to produce output. */
     @NonnullAfterInit private ObjectMapper jsonMapper;
     
     /** Formatting string for {@link DateTime} fields. */
     @Nullable private String dateTimeFormat;
 
     /** Whether this component has been initialized. */
@@ -201,7 +202,7 @@ public class HTTPReporter extends ScheduledReporter implements InitializableComp
     }
     
     /**
      * Set the {@link DateTime} formatting string to apply when writing {@link DateTime}-valued fields.
      * 
      * @param format formatting string
      */
@@ -98,7 +99,7 @@ public class HTTPReporter extends ScheduledReporter implements InitializableComp
     @NonnullAfterInit private ObjectMapper jsonMapper;
     
-    /** Formatting string for {@link DateTime} fields. */
+    /** Formatting string for {@link DateFormat} fields. */
     @Nullable private String dateTimeFormat;
 
@@ -201,7 +202,7 @@ public class HTTPReporter extends ScheduledReporter implements InitializableComp
     
     /**
-     * Set the {@link DateTime} formatting string to apply when writing {@link DateTime}-valued fields.
+     * Set the {@link DateFormat} formatting string to apply when writing {@link DateFormat}-valued fields.
      * 
      * @param format formatting string

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list